==> robotframework-tidy-3.0b1.tar.gz: robotframework-tidy-3.0b1/robotidy/transformers/NormalizeSectionHeaderName.py <==
from robot.api.parsing import ModelTransformer, Token

from robotidy.disablers import skip_section_if_disabled
from robotidy.transformers import Transformer


class NormalizeSectionHeaderName(ModelTransformer):
    """
    Normalize section headers names.
    Robot Framework is quite flexible with the section header naming. Following lines are equal:

    ```robotframework
    *setting
    *** SETTINGS
    *** SettingS ***
    ```

    This transformer normalizes naming to follow ``*** SectionName ***`` format (with plural variant):

    ```robotframework
    *** Settings ***
    *** Keywords ***
    *** Test Cases ***
    *** Variables ***
    *** Comments ***
    ```

    Optional data after section header (for example data driven column names) is preserved.
    It is possible to upper case section header names by passing ``uppercase=True`` parameter:

    ```robotframework
    *** SETTINGS ***
    ```

    Supports global formatting params: ``--startline`` and ``--endline``.
    """

    def __init__(self, uppercase: bool = False):
        self.uppercase = uppercase

    @skip_section_if_disabled
    def visit_Section(self, node):  # noqa
        return self.generic_visit(node)

    def visit_SectionHeader(self, node):  # noqa
        if node.name and "task" in node.name.lower():
            name = "*** Tasks ***"
        else:
            name = {
                Token.SETTING_HEADER: "*** Settings ***",
                Token.VARIABLE_HEADER: "*** Variables ***",
                Token.TESTCASE_HEADER: "*** Test Cases ***",
                Token.KEYWORD_HEADER: "*** Keywords ***",
                Token.COMMENT_HEADER: "*** Comments ***",
            }[node.type]
        if self.uppercase:
            name = name.upper()
        # we only modify header token value in order to preserver optional data driven testing column names
        node.data_tokens[0].value = name
        return node

==> robotframework-tidy-3.5.0.tar.gz: robotframework-tidy-3.5.0/robotidy/transformers/NormalizeSectionHeaderName.py <==
import string

from robot.api.parsing import Token

from robotidy.disablers import skip_section_if_disabled
from robotidy.transformers import Transformer


class NormalizeSectionHeaderName(Transformer):
    """
    Normalize section headers names.
    Robot Framework is quite flexible with the section header naming. Following lines are equal:

    ```robotframework
    *setting
    *** SETTINGS
    *** SettingS ***
    ```

    This transformer normalizes naming to follow ``*** SectionName ***`` format (with plural variant):

    ```robotframework
    *** Settings ***
    *** Keywords ***
    *** Test Cases ***
    *** Variables ***
    *** Comments ***
    ```

    Optional data after section header (for example data driven column names) is preserved.
    It is possible to upper case section header names by passing ``uppercase=True`` parameter:

    ```robotframework
    *** SETTINGS ***
    ```
    """

    EN_SINGULAR_HEADERS = {"comment", "setting", "variable", "task", "test case", "keyword"}

    def __init__(self, uppercase: bool = False):
        super().__init__()
        self.uppercase = uppercase

    @skip_section_if_disabled
    def visit_Section(self, node):  # noqa
        return self.generic_visit(node)

    def visit_SectionHeader(self, node):  # noqa
        if not node.name:
            return node
        # only normalize, and if found in english ones then add plural
        header_name = node.data_tokens[0].value
        header_name = header_name.replace("*", "").strip()
        if header_name.lower() in self.EN_SINGULAR_HEADERS:
            header_name += "s"
        if self.uppercase:
            header_name = header_name.upper()
        else:
            header_name = string.capwords(header_name)
        # we only modify header token value in order to preserver optional data driven testing column names
        node.data_tokens[0].value = f"*** {header_name} ***"
        return node
